@@ -98,10 +98,17 @@ def qubits(clArgs=None):
     if clArgs == None:
         clArgs = docopt(qubits.__doc__)
 
+    pathToOutputDirectory = os.path.abspath(pathToOutputDirectory)
+
     pathToOutputDirectory = clArgs["<pathToOutputDirectory>"]
     pathToSettingsFile = clArgs["<pathToSettingsFile>"]
     pathToSpectralDatabase = clArgs["<pathToSpectralDatabase>"]
 
+    pathToOutputDirectory = os.path.abspath(pathToOutputDirectory)
+    pathToSettingsFile = os.path.abspath(pathToSettingsFile)
+    pathToSpectralDatabase = os.path.abspath(pathToSpectralDatabase)
+
+
     ## IMPORT THE SIMULATION SETTINGS
     (allSettings,
     programSettings,
