@@ -274,7 +274,8 @@ def plot_sn_discovery_map(log,
         polar=True,
         frameon=False)
 
-    ax.set_ylim(0, 1.1)
+    maxInList = max(redshifts)
+    ax.set_ylim(0, maxInList)
     # ax.get_xaxis().set_visible(False)
 
     circleTicks = np.arange(0, 350, 30)
@@ -679,6 +680,8 @@ def determine_sn_rate(
         #polynomialDict["Detected - campaign to short to constrain as transient"] = shortCampaigntransientCurve
         orginalDataDictionary["Detected - campaign to short to constrain as transient"] = [shellRedshiftArray, shelltransientRateDensityArray*shortCampaignFractionListArray]
 
+    maxInList = max(redshifts)
+
     if pleasePlot:
         imageLink = dp.plot_polynomial(
                 log,
@@ -686,7 +689,7 @@ def determine_sn_rate(
                 polynomialDict=polynomialDict,
                 orginalDataDictionary=orginalDataDictionary,
                 pathToOutputPlotsFolder=pathToOutputPlotFolder,
-                xRange=[0.01, 1., 0.01],
+                xRange=[0.01, maxInList, 0.01],
                 xlabel=False,
                 ylabel=False,
                 xAxisLimits=False,
